@@ -16,6 +16,18 @@ SMALL_TIMEOUT = 7
 LARGE_TIMEOUT = 10
 EXTREME_TIMEOUT = 30
 
+# Default page load timeout.
+# If a page takes longer than this to load, you'll get the following error:
+#     selenium.common.exceptions.TimeoutException:
+#     Message: timeout: Timed out receiving message from renderer: PLT
+# In global Selenium settings, this value is set to 300 seconds by default.
+PAGE_LOAD_TIMEOUT = 120
+
+# Default page load strategy.
+# ["normal", "eager", "none"]
+# Selenium default = "normal"
+PAGE_LOAD_STRATEGY = "normal"
+
 # If True, existing logs from past test runs will be saved and take up space.
 # If False, only the logs from the most recent test run will be saved locally.
 # You can also archive existing logs on the command line with: "--archive_logs"
@@ -25,6 +37,13 @@ ARCHIVE_EXISTING_LOGS = False
 # If False, only the downloads from the most recent run will be saved locally.
 ARCHIVE_EXISTING_DOWNLOADS = False
 
+# If True, the last page screenshot will include the <body> and background.
+# If False, the last page screenshot will only include the <body> section.
+# Depending on the screen size, including a background could make the <body>
+# appear very small in the screenshot, which may require manually zooming in
+# on the <body> to see page details if you decide to include the background.
+SCREENSHOT_WITH_BACKGROUND = False
+
 # Default names for files saved during test failures.
 # (These files will get saved to the "latest_logs/" folder.)
 SCREENSHOT_NAME = "screenshot.png"
@@ -48,19 +67,17 @@ If False, the browser will stay on the current tab where the click happened.
 SWITCH_TO_NEW_TABS_ON_CLICK = True
 
 """
-This adds wait_for_ready_state_complete() after various browser actions.
-Setting this to True may improve reliability at the cost of speed.
+These methods add global waits, such as self.wait_for_ready_state_complete(),
+which waits for document.readyState to be "complete" after browser actions.
 """
-# Called after self.open(url) or self.open_url(url), NOT self.driver.open(url)
+# Called after self.open(URL), NOT driver.get(URL)
 WAIT_FOR_RSC_ON_PAGE_LOADS = True
 # Called after self.click(selector), NOT element.click()
 WAIT_FOR_RSC_ON_CLICKS = False
-
-"""
-This adds wait_for_angularjs() after various browser actions.
-(Requires WAIT_FOR_RSC_ON_PAGE_LOADS and WAIT_FOR_RSC_ON_CLICKS to also be on.)
-"""
+# Wait for AngularJS calls to complete after various browser actions.
 WAIT_FOR_ANGULARJS = True
+# Skip all calls to wait_for_ready_state_complete() and wait_for_angularjs().
+SKIP_JS_WAITS = False
 
 # Default time to wait after each browser action performed during Demo Mode.
 # Use Demo Mode when you want others to see what your automation is doing.
@@ -93,14 +110,24 @@ DISABLE_CSP_ON_CHROME = False
 # (This applies when using --proxy=[PROXY_STRING] for using a proxy server.)
 RAISE_INVALID_PROXY_STRING_EXCEPTION = True
 
+# Default browser coordinates when opening new windows for tests.
+WINDOW_START_X = 20
+WINDOW_START_Y = 54
+
 # Default browser resolutions when opening new windows for tests.
 # (Headless resolutions take priority, and include all browsers.)
 # (Firefox starts maximized by default when running in GUI Mode.)
-CHROME_START_WIDTH = 1250
+CHROME_START_WIDTH = 1280
 CHROME_START_HEIGHT = 840
 HEADLESS_START_WIDTH = 1440
 HEADLESS_START_HEIGHT = 1880
 
+# If True, hides messages related to downloading drivers.
+# If False, you'll see details about downloading drivers.
+# (This only affects driver downloads coming from tests.)
+# (If calling "sbase get chromedriver", then won't hide.)
+HIDE_DRIVER_DOWNLOADS = False
+
 # #####>>>>>----- MasterQA SETTINGS -----<<<<<#####
 # ##### (Used when importing MasterQA as the parent class)
 
