@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Creates a new folder for running SeleniumBase scripts.
 
@@ -19,7 +18,6 @@ Output:
     and Python boilerplates for setting up customized
     test frameworks.
 """
-
 import codecs
 import colorama
 import os
@@ -29,18 +27,18 @@ import sys
 def invalid_run_command(msg=None):
     exp = "  ** mkdir **\n\n"
     exp += "  Usage:\n"
-    exp += "          seleniumbase mkdir [DIRECTORY] [OPTIONS]\n"
-    exp += "          OR     sbase mkdir [DIRECTORY] [OPTIONS]\n"
+    exp += "     seleniumbase mkdir [DIRECTORY] [OPTIONS]\n"
+    exp += "     OR     sbase mkdir [DIRECTORY] [OPTIONS]\n"
     exp += "  Example:\n"
-    exp += "          sbase mkdir ui_tests\n"
+    exp += "     sbase mkdir ui_tests\n"
     exp += "  Options:\n"
-    exp += "          -b / --basic  (Only config files. No tests added.)\n"
+    exp += "     -b / --basic  (Only config files. No tests added.)\n"
     exp += "  Output:\n"
-    exp += "          Creates a new folder for running SBase scripts.\n"
-    exp += "          The new folder contains default config files,\n"
-    exp += "          sample tests for helping new users get started,\n"
-    exp += "          and Python boilerplates for setting up customized\n"
-    exp += "          test frameworks.\n"
+    exp += "     Creates a new folder for running SBase scripts.\n"
+    exp += "     The new folder contains default config files,\n"
+    exp += "     sample tests for helping new users get started,\n"
+    exp += "     and Python boilerplates for setting up customized\n"
+    exp += "     test frameworks.\n"
     if not msg:
         raise Exception("INVALID RUN COMMAND!\n\n%s" % exp)
     elif msg == "help":
@@ -56,7 +54,6 @@ def main():
     c7 = ""
     cr = ""
     if "linux" not in sys.platform:
-        colorama.init(autoreset=True)
         c1 = colorama.Fore.BLUE + colorama.Back.LIGHTCYAN_EX
         c5 = colorama.Fore.RED + colorama.Back.LIGHTYELLOW_EX
         c7 = colorama.Fore.BLACK + colorama.Back.MAGENTA
@@ -123,10 +120,8 @@ def main():
 
     data = []
     data.append("[pytest]")
-    data.append(
-        "addopts = --capture=no -p no:cacheprovider "
-        "--pdbcls=IPython.terminal.debugger:TerminalPdb"
-    )
+    data.append("addopts = --capture=tee-sys -p no:cacheprovider")
+    data.append("norecursedirs = .* build dist recordings temp assets")
     data.append("filterwarnings =")
     data.append("    ignore::pytest.PytestWarning")
     data.append("    ignore:.*U.*mode is deprecated:DeprecationWarning")
@@ -164,6 +159,7 @@ def main():
     data = []
     data.append("[flake8]")
     data.append("exclude=recordings,temp")
+    data.append("ignore=W503")
     data.append("")
     data.append("[nosetests]")
     data.append("nocapture=1")
@@ -172,9 +168,6 @@ def main():
     data.append("[behave]")
     data.append("show_skipped=false")
     data.append("show_timings=false")
-    data.append("")
-    data.append("[bdist_wheel]")
-    data.append("universal=1")
     file_path = "%s/%s" % (dir_name, "setup.cfg")
     file = codecs.open(file_path, "w+", "utf-8")
     file.writelines("\r\n".join(data))
@@ -193,7 +186,7 @@ def main():
     data.append("*.egg-info")
     data.append("dist")
     data.append("build")
-    data.append("ghostdriver.log")
+    data.append(".eggs")
     data.append("eggs")
     data.append("parts")
     data.append("bin")
@@ -225,6 +218,7 @@ def main():
     data.append("pip-selfcheck.json")
     data.append("ipython.1.gz")
     data.append("nosetests.1")
+    data.append(".noseids")
     data.append("pip-log.txt")
     data.append(".swp")
     data.append(".coverage")
@@ -244,6 +238,7 @@ def main():
     data.append("geckodriver")
     data.append("msedgedriver")
     data.append("operadriver")
+    data.append("uc_driver")
     data.append("MicrosoftWebDriver.exe")
     data.append("headless_ie_selenium.exe")
     data.append("IEDriverServer.exe")
@@ -251,17 +246,41 @@ def main():
     data.append("geckodriver.exe")
     data.append("msedgedriver.exe")
     data.append("operadriver.exe")
+    data.append("uc_driver.exe")
+    data.append("chrome-mac-arm64.zip")
+    data.append("chrome-mac-x64.zip")
+    data.append("chrome-linux64.zip")
+    data.append("chrome-win64.zip")
+    data.append("chrome-win32.zip")
+    data.append("chrome-mac-arm64")
+    data.append("chrome-mac-x64")
+    data.append("chrome-linux64")
+    data.append("chrome-win64")
+    data.append("chrome-win32")
+    data.append("chrome-headless-shell-mac-arm64.zip")
+    data.append("chrome-headless-shell-mac-x64.zip")
+    data.append("chrome-headless-shell-linux64.zip")
+    data.append("chrome-headless-shell-win64.zip")
+    data.append("chrome-headless-shell-win32.zip")
+    data.append("chrome-headless-shell-mac-arm64")
+    data.append("chrome-headless-shell-mac-x64")
+    data.append("chrome-headless-shell-linux64")
+    data.append("chrome-headless-shell-win64")
+    data.append("chrome-headless-shell-win32")
+    data.append("libc++.dylib")
     data.append("logs")
     data.append("latest_logs")
     data.append("log_archives")
     data.append("archived_logs")
     data.append("geckodriver.log")
+    data.append("ghostdriver.log")
     data.append("pytestdebug.log")
     data.append("reports/*.xml")
     data.append("latest_report")
     data.append("report_archives")
     data.append("archived_reports")
     data.append("html_report.html")
+    data.append("last_report.html")
     data.append("report.html")
     data.append("report.xml")
     data.append("dashboard.html")
@@ -319,6 +338,7 @@ def main():
 
     data = []
     data.append("from seleniumbase import BaseCase")
+    data.append("BaseCase.main(__name__, __file__)")
     data.append("")
     data.append("")
     data.append("class MyTestClass(BaseCase):")
@@ -327,24 +347,25 @@ def main():
     data.append('        self.type("#user-name", "standard_user")')
     data.append('        self.type("#password", "secret_sauce\\n")')
     data.append('        self.assert_element("div.inventory_list")')
-    data.append('        self.assert_text("PRODUCTS", "span.title")')
+    data.append('        self.assert_text("Products", "span.title")')
     data.append("        self.click('button[name*=\"backpack\"]')")
     data.append('        self.click("#shopping_cart_container a")')
-    data.append('        self.assert_text("YOUR CART", "span.title")')
+    data.append('        self.assert_text("Your Cart", "span.title")')
     data.append('        self.assert_text("Backpack", "div.cart_item")')
     data.append('        self.click("button#checkout")')
     data.append('        self.type("#first-name", "SeleniumBase")')
     data.append('        self.type("#last-name", "Automation")')
     data.append('        self.type("#postal-code", "77123")')
     data.append('        self.click("input#continue")')
-    data.append('        self.assert_text("CHECKOUT: OVERVIEW")')
+    data.append('        self.assert_text("Checkout: Overview")')
     data.append('        self.assert_text("Backpack", "div.cart_item")')
     data.append('        self.click("button#finish")')
     data.append(
-        '        self.assert_exact_text("THANK YOU FOR YOUR ORDER", "h2")'
+        '        self.assert_exact_text("Thank you for your order!", "h2")'
     )
     data.append("        self.assert_element('img[alt=\"Pony Express\"]')")
     data.append('        self.js_click("a#logout_sidebar_link")')
+    data.append('        self.assert_element("div#login_button_container")')
     data.append("")
     file_path = "%s/%s" % (dir_name, "my_first_test.py")
     file = codecs.open(file_path, "w+", "utf-8")
@@ -353,6 +374,7 @@ def main():
 
     data = []
     data.append("from seleniumbase import BaseCase")
+    data.append("BaseCase.main(__name__, __file__)")
     data.append("")
     data.append("")
     data.append("class DemoSiteTests(BaseCase):")
@@ -364,13 +386,19 @@ def main():
     data.append('        self.type("#myTextInput", "This is Automated")')
     data.append('        self.type("textarea.area1", "Testing Time!\\n")')
     data.append('        self.type(\'[name="preText2"]\', "Typing Text!")')
+    data.append(
+        '        self.assert_text("This is Automated", "#myTextInput")'
+    )
+    data.append(
+        '        self.assert_text("Testing Time!\\n", "textarea.area1")'
+    )
+    data.append(
+        '        self.assert_text("Typing Text!", \'[name="preText2"]\')'
+    )
     data.append('        self.assert_text("Automation Practice", "h3")')
-    data.append("        try:")
-    data.append("            self.hover_and_click(")
-    data.append('                "#myDropdown", "#dropOption2", timeout=1)')
-    data.append("        except Exception:")
-    data.append("            # If someone moves the mouse while the test runs")
-    data.append('            self.js_click("#dropOption2")')
+    data.append(
+        '        self.hover_and_js_click("#myDropdown", "#dropOption2")'
+    )
     data.append('        self.assert_text("Link Two Selected", "h3")')
     data.append('        self.assert_text("This Text is Green", "#pText")')
     data.append('        self.click("#myButton")')
@@ -427,7 +455,8 @@ def main():
     data.append('        self.click_link("SeleniumBase Demo Page")')
     data.append('        self.assert_exact_text("Demo Page", "h1")')
     data.append('        self.highlight("h2")')
-    data.append("        self.demo_mode = True")
+    data.append('        if self.headed:')
+    data.append("            self.activate_demo_mode()")
     data.append('        self.type("input", "Have a Nice Day!")')
     data.append('        self.assert_text("SeleniumBase", "h2")')
     data.append("")
@@ -439,25 +468,36 @@ def main():
     data = []
     data.append("from parameterized import parameterized")
     data.append("from seleniumbase import BaseCase")
+    data.append("BaseCase.main(__name__, __file__)")
     data.append("")
     data.append("")
-    data.append("class GoogleTests(BaseCase):")
+    data.append("class SearchTests(BaseCase):")
     data.append("    @parameterized.expand(")
     data.append("        [")
-    data.append('            ["Download Python", "Download Python"],')
-    data.append('            ["wikipedia", "wikipedia.org"],')
-    data.append('            ["seleniumbase", "SeleniumBase"],')
+    data.append(
+        "            "
+        '["SeleniumBase Commander", "Commander", "GUI / Commander"],'
+    )
+    data.append(
+        '            ["SeleniumBase Recorder", "Recorder", "Recorder Mode"],'
+    )
+    data.append(
+        '            ["SeleniumBase Syntax", "Syntax", "Syntax Formats"],'
+    )
     data.append("        ]")
     data.append("    )")
     data.append(
-        "    def test_parameterized_google_search("
-        "self, search_term, expected_text):"
+        "    def test_parameterized_search("
+        "self, search_term, keyword, title_text):"
     )
-    data.append('        self.open("https://google.com/ncr")')
     data.append(
-        '        self.type(\'input[title="Search"]\', search_term + "\\n")'
+        '        self.open("https://seleniumbase.io/help_docs/how_it_works/")'
     )
-    data.append('        self.assert_text(expected_text, "#search")')
+    data.append(
+        '        self.type(\'[aria-label="Search"]\', search_term)'
+    )
+    data.append('        self.click(\'mark:contains("%s")\' % keyword)')
+    data.append('        self.assert_title_contains(title_text)')
     data.append("")
     file_path = "%s/%s" % (dir_name, "parameterized_test.py")
     file = codecs.open(file_path, "w+", "utf-8")
@@ -476,14 +516,12 @@ def main():
 
     data = []
     data.append("from seleniumbase import BaseCase")
+    data.append("BaseCase.main(__name__, __file__)")
     data.append("")
     data.append("")
     data.append("class BaseTestCase(BaseCase):")
     data.append("    def setUp(self):")
-    if sys.version_info[0] >= 3:
-        data.append("        super().setUp()")
-    else:
-        data.append("        super(BaseTestCase, self).setUp()")
+    data.append("        super().setUp()")
     data.append("        # <<< Run custom code AFTER the super() line >>>")
     data.append("")
     data.append("    def tearDown(self):")
@@ -496,10 +534,7 @@ def main():
     data.append("            pass")
     data.append("        # (Wrap unreliable code in a try/except block.)")
     data.append("        # <<< Run custom code BEFORE the super() line >>>")
-    if sys.version_info[0] >= 3:
-        data.append("        super().tearDown()")
-    else:
-        data.append("        super(BaseTestCase, self).tearDown()")
+    data.append("        super().tearDown()")
     data.append("")
     data.append("    def login(self):")
     data.append("        # <<< Placeholder. Add your code here. >>>")
@@ -541,6 +576,7 @@ def main():
 
     data = []
     data.append("from seleniumbase import BaseCase")
+    data.append("BaseCase.main(__name__, __file__)")
     data.append("")
     data.append("")
     data.append("class DataPage:")
@@ -595,20 +631,30 @@ def main():
     data = []
     data.append("from seleniumbase import BaseCase")
     data.append("from .google_objects import HomePage, ResultsPage")
+    data.append('BaseCase.main(__name__, __file__, "--uc")')
     data.append("")
     data.append("")
     data.append("class GoogleTests(BaseCase):")
     data.append("    def test_google_dot_com(self):")
+    data.append("        if not self.undetectable:")
+    data.append("            self.get_new_driver(undetectable=True)")
     data.append('        self.open("https://google.com/ncr")')
-    data.append('        self.type(HomePage.search_box, "github")')
-    data.append("        self.assert_element(HomePage.list_box)")
+    data.append('        self.assert_title_contains("Google")')
+    data.append("        self.sleep(0.05)")
+    data.append("        self.save_screenshot_to_logs()")
+    data.append(
+        "        self.wait_for_element('iframe[role=\"presentation\"]')"
+    )
+    data.append("        self.hide_elements('iframe')")
+    data.append("        self.sleep(0.05)")
+    data.append("        self.save_screenshot_to_logs()")
+    data.append('        self.type(HomePage.search_box, "github.com")')
     data.append("        self.assert_element(HomePage.search_button)")
     data.append("        self.assert_element(HomePage.feeling_lucky_button)")
     data.append("        self.click(HomePage.search_button)")
     data.append(
         '        self.assert_text("github.com", ResultsPage.search_results)'
     )
-    data.append("        self.assert_element(ResultsPage.images_link)")
     data.append("")
     file_path = "%s/%s" % (dir_name_3, "google_test.py")
     file = codecs.open(file_path, "w+", "utf-8")
@@ -618,8 +664,7 @@ def main():
     data = []
     data.append("class HomePage(object):")
     data.append("    dialog_box = '[role=\"dialog\"] div'")
-    data.append("    search_box = 'input[title=\"Search\"]'")
-    data.append("    list_box = '[role=\"listbox\"]'")
+    data.append("    search_box = '[title=\"Search\"]'")
     data.append("    search_button = 'input[value=\"Google Search\"]'")
     data.append(
         '    feeling_lucky_button = """input[value="I\'m Feeling Lucky"]"""'
@@ -627,8 +672,6 @@ def main():
     data.append("")
     data.append("")
     data.append("class ResultsPage(object):")
-    data.append("    google_logo = 'img[alt=\"Google\"]'")
-    data.append('    images_link = "link=Images"')
     data.append('    search_results = "div#center_col"')
     data.append("")
     file_path = "%s/%s" % (dir_name_3, "google_objects.py")
@@ -640,6 +683,7 @@ def main():
     data.append('""" Classic Page Object Model with BaseCase inheritance """')
     data.append("")
     data.append("from seleniumbase import BaseCase")
+    data.append("BaseCase.main(__name__, __file__)")
     data.append("")
     data.append("")
     data.append("class LoginPage:")
@@ -659,6 +703,8 @@ def main():
     data.append(
         "        self.assert_element('div:contains(\"Sauce Labs Backpack\")')"
     )
+    data.append('        self.js_click("a#logout_sidebar_link")')
+    data.append('        self.assert_element("div#login_button_container")')
     data.append("")
     file_path = "%s/%s" % (dir_name_3, "swag_labs_test.py")
     file = codecs.open(file_path, "w+", "utf-8")
@@ -684,6 +730,8 @@ def main():
     data.append(
         "        sb.assert_element('div:contains(\"Sauce Labs Backpack\")')"
     )
+    data.append('        sb.js_click("a#logout_sidebar_link")')
+    data.append('        sb.assert_element("div#login_button_container")')
     data.append("")
     file_path = "%s/%s" % (dir_name_3, "sb_swag_test.py")
     file = codecs.open(file_path, "w+", "utf-8")
