@@ -1,7 +1,4 @@
-"""
-The plugin for capturing and storing the page source on errors and failures.
-"""
-
+"""PageSource Plugin for SeleniumBase tests that run with pynose / nosetests"""
 import os
 import codecs
 from nose.plugins import Plugin
@@ -10,20 +7,15 @@ from seleniumbase.core import log_helper
 
 
 class PageSource(Plugin):
-    """
-    This plugin will capture the page source when a test fails
-    or raises an error. It will store the page source in the
-    logs file specified, along with default test information.
-    """
-
+    """Capture the page source after a test fails."""
     name = "page_source"  # Usage: --with-page_source
     logfile_name = settings.PAGE_SOURCE_NAME
 
     def options(self, parser, env):
-        super(PageSource, self).options(parser, env=env)
+        super().options(parser, env=env)
 
     def configure(self, options, conf):
-        super(PageSource, self).configure(options, conf)
+        super().configure(options, conf)
         if not self.enabled:
             return
         self.options = options
@@ -32,12 +24,11 @@ class PageSource(Plugin):
         try:
             page_source = test.driver.page_source
         except Exception:
-            # Since we can't get the page source from here, skip saving it
             return
         test_logpath = self.options.log_path + "/" + test.id()
         if not os.path.exists(test_logpath):
             os.makedirs(test_logpath)
-        html_file_name = "%s/%s" % (test_logpath, self.logfile_name)
+        html_file_name = os.path.join(test_logpath, self.logfile_name)
         html_file = codecs.open(html_file_name, "w+", "utf-8")
         rendered_source = log_helper.get_html_source_with_base_href(
             test.driver, page_source
@@ -49,12 +40,11 @@ class PageSource(Plugin):
         try:
             page_source = test.driver.page_source
         except Exception:
-            # Since we can't get the page source from here, skip saving it
             return
         test_logpath = self.options.log_path + "/" + test.id()
         if not os.path.exists(test_logpath):
             os.makedirs(test_logpath)
-        html_file_name = "%s/%s" % (test_logpath, self.logfile_name)
+        html_file_name = os.path.join(test_logpath, self.logfile_name)
         html_file = codecs.open(html_file_name, "w+", "utf-8")
         rendered_source = log_helper.get_html_source_with_base_href(
             test.driver, page_source
